var Child = /*#__PURE__*/function (_Base) {
  "use strict";

  babelHelpers.inheritsLoose(Child, _Base);

  function Child() {
    var _this;

    return false || babelHelpers.assertThisInitialized(_this);
  }

  return Child;
}(Base);
